==> Evergreen-ILS-3.15.9.tar.gz: Evergreen-ILS-3.15.9/Open-ILS/web/js/dojo/openils/actor/nls/de-de/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "MITTEILEN",
    ":DELETE_ADDRESS": "L\u00f6schen Adresse ${0}?",
    ":NEED_ADDRESS": "Eine Adresse ist w\u00e4hrend der Registrierung erforderlich.",
    ":DUPE_PATRON_NAME": "${0} Bibliotheksnutzer mit dem selben Namen gefunden",
    ":DUPE_PATRON_EMAIL": "${0} Bibliotheksnutzer mit der selben E-Mail Adresse gefunden",
    ":DUPE_PATRON_IDENT": "Fand $(0) Patrone(n) mit derselben Identifikation",
    ":DUPE_PATRON_PHONE": "${0} Bibliotheksnutzer mit der selben Telefonnummer gefunden.",
    ":DUPE_PATRON_ADDR": "${0} Bibliotheksnutzer mit der selben Adresse gefunden",
    ":REPLACED_ADDRESS": "Replaces address ${0}<br/> ${1} ${2}<br/> ${3}, ${4} ${5}",
    ":INVALID_FORM": "Form ist ung\u00fcltigt. Bitte bearbeiten und neu versuchen.",
    ":EXAMPLE": "Beispiel: ",
    ":REPLACE_BARCODE": "Barcode ersetzen",
    ":BARCODE_IN_USE": "Barcode wird bereits benutzt",
    ":SEE_ALL": "Alles anzeigen",
    ":DUPE_USERNAME": "Benutzername wird bereits benutzt",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Passwort best\u00e4tigen",
    ":PARENT_OR_GUARDIAN": "Eltern/Vormund",
    ":USER_SETTINGS": "Benutzereinstellungen",
    ":ADDRESS_HEADER": "Adresse",
    ":ADDRESS_MAILING": "Mailversand",
    ":ADDRESS_BILLING": "Abrechnung",
    ":ADDRESS_PENDING": "Dies ist eine unbest\u00e4tigte Adresse: ",
    ":ADDRESS_APPROVE": "Gepr\u00fcfte Adresse",
    ":ADDRESS_OWNED": "Diese Adresse geh\u00f6rt einem anderen Benutzer: ",
    ":ADDRESS_NEW": "Neue Adresse",
    ":STAT_CATS": "Statistische Kategorien",
    ":SAVE": "Speichern",
    ":SAVE_CLONE": "Speichere &amp; Klon",
    ":SHOW_REQUIRED": "Nur ben\u00f6tigte Felder anzeigen",
    ":SHOW_SUGGESTED": "Vorgeschlagene Felder anzeigen",
    ":SHOW_ALL": "Alle Felder anzeigen",
    ":ALL_CARDS_BARCODE": "Barcode",
    ":ALL_CARDS_ACTIVE": "Active",
    ":ALL_CARDS_PRIMARY": "Primary",
    ":ALL_CARDS_CLOSE": "Close",
    ":ALL_CARDS_APPLY": "\u00c4nderungen anwenden",
    ":INVALIDATE": "Invalidate",
    ":HOLD_NOTIFY_PHONE": "Phone: ",
    ":HOLD_NOTIFY_EMAIL": "Email: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}

==> Evergreen-ILS-3.16.2.tar.gz: Evergreen-ILS-3.16.2/Open-ILS/web/js/dojo/openils/actor/nls/de-de/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "MITTEILEN",
    ":DELETE_ADDRESS": "L\u00f6schen Adresse ${0}?",
    ":NEED_ADDRESS": "Eine Adresse ist w\u00e4hrend der Registrierung erforderlich.",
    ":DUPE_PATRON_NAME": "${0} Bibliotheksnutzer mit dem selben Namen gefunden",
    ":DUPE_PATRON_EMAIL": "${0} Bibliotheksnutzer mit der selben E-Mail Adresse gefunden",
    ":DUPE_PATRON_IDENT": "Fand $(0) Patrone(n) mit derselben Identifikation",
    ":DUPE_PATRON_PHONE": "${0} Bibliotheksnutzer mit der selben Telefonnummer gefunden.",
    ":DUPE_PATRON_ADDR": "${0} Bibliotheksnutzer mit der selben Adresse gefunden",
    ":REPLACED_ADDRESS": "<div>Ersetzt Adresse <b>${0}</b><br/> ${1} ${2}<br/> ${3}, ${4} ${5}</div>",
    ":INVALID_FORM": "Form ist ung\u00fcltigt. Bitte bearbeiten und neu versuchen.",
    ":EXAMPLE": "Beispiel: ",
    ":REPLACE_BARCODE": "Barcode ersetzen",
    ":BARCODE_IN_USE": "Barcode wird bereits benutzt",
    ":SEE_ALL": "Alles anzeigen",
    ":DUPE_USERNAME": "Benutzername wird bereits benutzt",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "Passwort best\u00e4tigen",
    ":PARENT_OR_GUARDIAN": "Eltern/Vormund",
    ":PARENT_OR_GUARDIAN_EMAIL": "Parent/Guardian Email",
    ":USER_SETTINGS": "Benutzereinstellungen",
    ":ADDRESS_HEADER": "Adresse",
    ":ADDRESS_MAILING": "Mailversand",
    ":ADDRESS_BILLING": "Abrechnung",
    ":ADDRESS_PENDING": "Dies ist eine unbest\u00e4tigte Adresse: ",
    ":ADDRESS_APPROVE": "Gepr\u00fcfte Adresse",
    ":ADDRESS_OWNED": "Diese Adresse geh\u00f6rt einem anderen Benutzer: ",
    ":ADDRESS_NEW": "Neue Adresse",
    ":STAT_CATS": "Statistische Kategorien",
    ":SAVE": "Speichern",
    ":SAVE_CLONE": "Speichere &amp; Klon",
    ":SHOW_REQUIRED": "Nur ben\u00f6tigte Felder anzeigen",
    ":SHOW_SUGGESTED": "Vorgeschlagene Felder anzeigen",
    ":SHOW_ALL": "Alle Felder anzeigen",
    ":ALL_CARDS_BARCODE": "Barcode",
    ":ALL_CARDS_ACTIVE": "Active",
    ":ALL_CARDS_PRIMARY": "Primary",
    ":ALL_CARDS_CLOSE": "Close",
    ":ALL_CARDS_APPLY": "\u00c4nderungen anwenden",
    ":INVALIDATE": "Invalidate",
    ":HOLD_NOTIFY_PHONE": "Phone: ",
    ":HOLD_NOTIFY_EMAIL": "Email: ",
    ":HOLD_NOTIFY_SMS": "SMS: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}
